# OpenAI holds back wide release of voice-cloning tech due to misuse concerns
## Voice Engine can clone voices with 15 seconds of audio, but OpenAI is warning of potential misuse.
## Information:

+ Link: https://arstechnica.com/information-technology/2024/03/openai-holds-back-wide-release-of-voice-cloning-tech-due-to-misuse-concerns/
+ Source: Ars Technica
+ Author: Benj Edwards
+ Date published: 29 March 2024, 17:13
+ Date scraped: 29 March 2024, 18:03

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2024/03/GettyImages-14580452381-760x380.jpg)



Voice synthesis has come a long way since 1978's [Speak & Spell](https://www.vintagecomputing.com/index.php/archives/528/vcg-interview-richard-wiggins-talks-speak-spell) toy, which once wowed people with its state-of-the-art ability to read words aloud using an electronic voice. Now, using deep-learning AI models, software can create not only realistic-sounding voices, but also convincingly imitate existing voices using small samples of audio.


Along those lines, OpenAI just announced Voice Engine, a text-to-speech AI model for creating synthetic voices based on a 15-second segment of recorded audio. It has provided audio samples of the Voice Engine in action [on its website](http://openai.com/blog/navigating-the-challenges-and-opportunities-of-synthetic-voices).


Once a voice is cloned, a user can input text into the Voice Engine and get an AI-generated voice result. But OpenAI is not ready to widely release its technology yet. The company initially planned to launch a pilot program for developers to sign up for the Voice Engine API earlier this month. But after more consideration about ethical implications, the company decided to scale back its ambitions for now.


"In line with our approach to AI safety and our voluntary commitments, we are choosing to preview but not widely release this technology at this time," the company writes. "We hope this preview of Voice Engine both underscores its potential and also motivates the need to bolster societal resilience against the challenges brought by ever more convincing generative models."


Voice cloning tech in general is not particularly new—we've [covered](https://arstechnica.com/information-technology/2023/08/metas-massively-multilingual-ai-model-translates-up-to-100-languages-speech-or-text/) [several](https://arstechnica.com/information-technology/2023/01/microsofts-new-ai-can-simulate-anyones-voice-with-3-seconds-of-audio/) AI voice synthesis models since 2022, and the tech is active in the open source community with packages like [OpenVoice](https://research.myshell.ai/open-voice) and [XTTSv2](https://huggingface.co/coqui/XTTS-v2). But the idea that OpenAI is inching toward letting anyone use their particular brand of voice tech is notable. And in some ways, the company's reticence to release it fully might be the bigger story.


OpenAI says that benefits of its voice technology include providing reading assistance through natural-sounding voices, enabling global reach for creators by translating content while preserving native accents, supporting non-verbal individuals with personalized speech options, and assisting patients in recovering their own voice after speech-impairing conditions.


But it also means that anyone with 15 seconds of someone's recorded voice could effectively clone it, and that has obvious implications for potential misuse. Even if OpenAI never widely releases its Voice Engine, the ability to clone voices has already caused trouble in society through [phone scams](https://arstechnica.com/tech-policy/2023/03/rising-scams-use-ai-to-mimic-voices-of-loved-ones-in-financial-distress/) where someone imitates a loved one's voice and [election campaign robocalls](https://arstechnica.com/tech-policy/2024/01/robocall-with-artificial-joe-biden-voice-tells-democrats-not-to-vote/) featuring cloned voices from politicians like Joe Biden.


Also, researchers and reporters [have shown](https://www.vice.com/en/article/dy7axa/how-i-broke-into-a-bank-account-with-an-ai-generated-voice) that voice-cloning technology can be used to break into bank accounts that use voice authentication (such as Chase's [Voice ID](https://www.chase.com/personal/voice-biometrics)), which prompted Sen. Sherrod Brown (D-Ohio), the chairman of the US Senate Committee on Banking, Housing, and Urban Affairs, to send [a letter](https://www.banking.senate.gov/imo/media/doc/bank_of_america_voice_authentication_letter2.pdf) to the CEOs of [several major banks](https://www.banking.senate.gov/newsroom/majority/brown-presses-banks-voice-authentication-services) in May 2023 to inquire about the security measures banks are taking to counteract AI-powered risks.




[![A screenshot of Chase's Voice ID website captured on March 29, 2024. Many banks use heavily promoted voice authentication features that can be defeated with AI voice cloning tech, both open source and commercial.](https://cdn.arstechnica.net/wp-content/uploads/2024/03/chase_voiceid_screenshot-640x577.jpg)](https://cdn.arstechnica.net/wp-content/uploads/2024/03/chase_voiceid_screenshot.jpg) / A screenshot of Chase's Voice ID website captured on March 29, 2024. Many banks use heavily promoted voice authentication features that can be defeated with AI voice cloning tech, both open source and commercial.[Benj Edwards](https://www.chase.com/personal/voice-biometrics)


OpenAI recognizes that the tech might cause trouble if broadly released, so it's initially trying to work around those issues with a set of rules. It has been testing the technology with a set of select partner companies since last year. For example, video synthesis company [HeyGen](https://www.heygen.com/) has been using the model to translate a speaker's voice into other languages while keeping the same vocal sound.


To use Voice Engine, each partner must agree to terms of use that prohibit "the impersonation of another individual or organization without consent or legal right." The terms also require that partners acquire informed consent from the people whose voices are being cloned, and they must also clearly disclose that the voices they produce are AI-generated. OpenAI is also baking a watermark into every voice sample that will assist in tracing the origin of any voice generated by its Voice Engine model.


So, as it stands now, OpenAI is showing off its technology, but the company is not yet ready to put itself on the line (yet) for the potential social chaos a broad release might cause. Instead, the company has re-calibrated its marketing approach to appear as if it is warning all of us about this already-existing technology in a responsible way.


"We are taking a cautious and informed approach to a broader release due to the potential for synthetic voice misuse," the company said in a statement. "We hope to start a dialogue on the responsible deployment of synthetic voices and how society can adapt to these new capabilities. Based on these conversations and the results of these small scale tests, we will make a more informed decision about whether and how to deploy this technology at scale."


In line with its mission to cautiously roll out the tech, OpenAI has provided three recommendations for how society should change to accommodate its technology in its [blog post](http://openai.com/blog/navigating-the-challenges-and-opportunities-of-synthetic-voices). These steps include phasing out voice-based authentication for bank accounts, educating the public in understanding "the possibility of deceptive AI content," and accelerating the development of techniques that can track the origin of audio content, "so it's always clear when you're interacting with a real person or with an AI."


OpenAI also says that future voice-cloning tech should require verifying that the original speaker is "knowingly adding their voice to the service" and creating a list of voices that are forbidden to clone, such as those that are "too similar to prominent figures." That kind of screening tech may end up excluding anyone whose voice might naturally and accidentally sound too close to a celebrity or US president.


Tech developed in 2022
----------------------


According to the company, OpenAI developed its Voice Engine technology in late 2022, and many people have already been using a version of the technology with pre-defined (and not cloned) voices in two ways: The [spoken conversation mode](https://arstechnica.com/information-technology/2023/09/chatgpt-goes-multimodal-with-image-recognition-and-speech-synthesis/) in the ChatGPT app released in September and OpenAI's [text-to-speech API](https://platform.openai.com/docs/guides/text-to-speech) that [debuted](https://techcrunch.com/2023/11/06/openai-launches-dall-e-3-api-new-text-to-speech-models/) in November of last year.


With all the voice-cloning competition out there, OpenAI says that Voice Engine is notable for being a "small" AI model (how small, exactly, we do not know). But having been developed in 2022, it almost feels late to the party. And it may not be perfect in its cloning ability. Previous user-trained text-to-voice models like those from [ElevenLabs](https://arstechnica.com/information-technology/2023/11/unauthorized-david-attenborough-ai-clone-narrates-developers-life-goes-viral/) and [Microsoft](https://arstechnica.com/information-technology/2023/01/microsofts-new-ai-can-simulate-anyones-voice-with-3-seconds-of-audio/) have [struggled with accents](https://www.reddit.com/r/ElevenLabs/comments/10ye125/doesnt_work_well_with_accents/) that fall outside their training dataset.


For now, Voice Engine remains a limited release to select partners. But if we get a chance to experiment with OpenAI's voice-cloning technology ourselves, we'll let you know about it in a future report.





## Tags:


### Autogenerated tags:
[[openai]] [[voice-cloning]]
