# Hands on with WSLg: Running Linux GUI apps in Windows 10
## Windows 10 preview builds can now run Linux apps directly on the Windows 10 desktop using the new Windows Subsystem for Linux GUI. In this article, we go hands on with the new WSLg feature to demonstrate the types of graphical Linux apps you can now run.
## Information:

+ Link: https://www.bleepingcomputer.com/news/microsoft/hands-on-with-wslg-running-linux-gui-apps-in-windows-10/
+ Source: Bleeping Computer
+ Author: Lawrence Abrams
+ Date published: 29 May 2021, 10:18
+ Date scraped: 12 December 2023, 12:26

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2020/09/30/wsl-space-header.jpg)



Windows 10 preview builds can now run Linux apps directly on the Windows 10 desktop using the new Windows Subsystem for Linux GUI. In this article, we go hands on with the new WSLg feature to demonstrate the types of graphical Linux apps you can now run.


The Windows Subsystem for Linux GUI (WSLg) was officially released at the Microsoft Build 2021 conference and comes with Windows 10 Insider build 21364 or later.


WSLg can launch Linux GUI apps by utilizing the Wayland server to display the apps in Windows 10.


WSLg starts "a companion system distro, containing a Wayland, X server, pulse audio server, and everything else needed to make Linux GUI apps communicate with Windows," as Windows Developer Platform Program Manager Craig Loewen [explained](https://www.bleepingcomputer.com/news/microsoft/microsoft-windows-10-insiders-can-now-can-run-linux-gui-apps/).


Bundling WSLg with Windows 10 is an exciting development as it blurs the lines between Linux and Windows 10, and fans get the benefits of both worlds.


Installing WSLg
---------------


Before getting started with Windows Subsystem for Linux GUI. (WSLg), you first need to be running recent Windows 10 Insider builds on the 'Dev' channel. At the time of this writing, that build number is 21390.


Once the latest Windows 10 version is installed, you can install the Windows Subsystem for Linux and install a new Linux distribution.


For example, to install the Windows Subsystem for Linux (WSL) with GUI support and automatically install Ubuntu, you would enter the `wsl --install -d Ubuntu` at a [Windows 10 Elevated Command Prompt](https://www.bleepingcomputer.com/tutorials/how-to-open-a-windows-10-elevated-command-prompt/).


For existing WSL users, you need to update WSL to add support for the WSLg engine using the `wsl --update` command followed by `wsl --shutdown`, as shown below.


![](https://www.bleepstatic.com/images/news/Microsoft/Windows-10/w/wsl/WSLg/install-wslg.jpg)


Once WSL is updated, you need to make sure your installed Linux distribution is configured to use WSL 2 using the `wsl --list -v` command. 


![](https://www.bleepstatic.com/images/news/Microsoft/Windows-10/w/wsl/WSLg/check-version.jpg)


If the distribution you want to use is version 1, you need to upgrade it to version 2 using the `wsl --set-version _distro_name_ 2` command. For example, to upgrade kali-linux to WSL2, we would enter `wsl --set-version kali-linux 2` at a command prompt.


For better performance in WSLg, Microsoft recommends that you install the following preview drivers: [AMD GPU driver for WSL](https://community.amd.com/community/radeon-pro-graphics/blog/2020/06/17/announcing-amd-support-for-gpu-accelerated-machine-learning-training-on-windows-10), [Intel GPU driver for WSL](https://downloadcenter.intel.com/download/29526), and [NVIDIA GPU driver for WSL](https://developer.nvidia.com/cuda/wsl).


Once your distribution is upgraded, you can now use WSLg to run Linux GUI apps.


Running Linux GUI apps in Windows 10
------------------------------------


With Linux becoming more popular as a desktop operating over the past decade, more software developers have been creating Linux versions of their programs.


As popular programs, such as Microsoft Edge for Linux, Chrome for Linux, or even VLC Media Player for Linux, all have Windows variants, I illustrate some Linux-only GUI programs working under WSLG below instead.


### Nautilus


Nautilus is the official file manager for the Gnome Desktop. While you will likely find it easier to use File Explorer in Windows 10, Nautilus illustrates how applications of every type work under WSLg.



```
sudo apt install Nautilus
nautilus
```


![Nautilus in WSLg](https://www.bleepstatic.com/images/news/Microsoft/Windows-10/w/wsl/WSLg/nautilus.jpg)**Nautilus in WSLg**


### Stacer


Stacer is an open-source system optimizer and application monitor/task manager for Linux.


You can install and run Stacer with the following commands:



```
sudo apt install stacer
stacer
```


![Stacer showing running WSL processes](https://www.bleepstatic.com/images/news/Microsoft/Windows-10/w/wsl/WSLg/stacer.jpg)**Stacer showing running WSL processes**


### Timeshift


Timeshift is a backup software for Linux that can be used to create snapshots of your filesystems.


You can install and run Stacer with the following commands:



```
sudo apt install timeshift
sudo timeshift-gtk
```


![Timeshift on WSLg](https://www.bleepstatic.com/images/news/Microsoft/Windows-10/w/wsl/WSLg/timeshift.jpg)**Timeshift on WSLg**


### Hedgewars


While Hedgewars is not a Linux-only game, I wanted to include it to show that even games can run under WSLg. While WSLg is likely not designed for gaming, the fact that you can play games using it shows the full depth of this new feature.


You can install and run Hedgewars with the following commands:



```
sudo apt install hedgewars
hedgewars
```


![Hedgewars under WSLg](https://www.bleepstatic.com/images/news/Microsoft/Windows-10/w/wsl/WSLg/hedgewars.jpg)**Hedgewars under WSLg**


These three apps are just a few examples of the types of Linux programs you can now run under Windows 10, with many more available for free.





## Tags:


### Autogenerated tags:
[[linux]] [[windows]] [[wslg]] [[wsl]] [[gui]] [[apps]] [[stacer]] [[hedgewars]] [[sudo]] [[timeshift]]
