# Windows 10's package manager flooded with duplicate, malformed apps
## Microsoft's Windows 10 package manager Winget's GitHub has been flooded with duplicate apps and malformed manifest files raising concerns among developers with regards to the integrity of apps.
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/windows-10s-package-manager-flooded-with-duplicate-malformed-apps/
+ Source: Bleeping Computer
+ Author: Ax Sharma
+ Date published: 01 June 2021, 11:15
+ Date scraped: 12 December 2023, 12:21

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2021/05/17/0_Windows-headpic.jpg)



Last week, Microsoft [released](https://www.bleepingcomputer.com/news/microsoft/microsoft-releases-first-windows-10-package-manager-stable-version/) the first stable version of its Windows 10 package manager, Winget, which enables users to manage apps via command-line.


Much like package managers available on other platforms, Winget lets Windows users automate app management when it comes to installing, configuring, upgrading, and uninstalling applications.


But, over the weekend, multiple users flooded Winget's software registry with pull requests for apps that are either duplicate or malformed, thereby raising concerns about the integrity of the Winget ecosystem.


Winget's repo flooded with duplicate apps, malformed manifests
--------------------------------------------------------------


Microsoft had first introduced the preview version of its Windows 10 package manager at [Microsoft Build 2020](http://devblogs.microsoft.com/commandline/windows-package-manager-preview/). Since then, Microsoft developed Winget as an open-source project on GitHub.


Last week marked a milestone when the first stable version of Winget was [released](https://devblogs.microsoft.com/commandline/windows-package-manager-1-0/).


Microsoft's guidelines [state](https://docs.microsoft.com/en-gb/windows/package-manager/) that independent software vendors (ISVs) looking to upload their application to the Winget registry, can do so by submitting the application's manifest on their GitHub.


Furthermore, when contributors submit a manifest to Winget's GitHub, with some exceptions, the manifests are [automatically validated](https://docs.microsoft.com/en-gb/windows/package-manager/package/repository) by Winget's bot against set criteria.


But, over this Memorial Day weekend, multiple pull requests emerged on Winget's GitHub containing names of apps that had already existed in the package manager's registry.


Moreover, some pull requests contained incorrect application names in the manifests or "bad" links from where the application should get fetched.


And, in few other cases, new pull requests would **overwrite existing applications' manifests**, with incomplete info.


The user *KaranKad* originally [raised this issue](https://github.com/microsoft/winget-pkgs/issues/14621) over the weekend, after gathering over five dozen such examples of invalid pull requests being made to Winget's repo.


"People are submitting bad or duplicate manifests without checking if the app already exists or not in this repository."


"Create a group of active contributors who know what they are doing, with [the] ability to close a PR so they can prevent bad or duplicate PRs from getting in," suggested the user.


Out of the many examples posted, BleepingComputer noticed how this was especially true for an app named after "PrimoPDF":



![NitroPDF bad link Winget](https://www.bleepstatic.com/images/news/u/1164866/2021/Jun%202021/winget%20flooded/winget-nitropdf.jpg)**Incorrect Winget *PackageIdentifier* and *InstallerUrl* submitted for NitroPDF application (**[GitHub](https://github.com/microsoft/winget-pkgs/pull/14763/commits/cb60600e47229bf9864ad1a92b9fba5588b2b075))


The manifest files for the NitroPDF's PrimoPDF app reportedly contains malformed *PackageIdentifier* ("NitroPDFIncNitroPDFPtyLtd.PrimoPDF") and download URL.


In other cases, BleepingComputer observed, manifests of legitimate applications like VideoLAN's VLC player and Valve's Steam app had been overwritten by contributors, but with incomplete info:



![winget app overwritten](https://www.bleepstatic.com/images/news/u/1164866/2021/Jun%202021/winget%20flooded/winget-partial-info.jpg)**Manifest of VideoLAN's VLC player overwritten with incomplete info** ([GitHub](https://github.com/microsoft/winget-pkgs/commit/89e5fb0a4f0d2e5cf4d53be60033cffb01eebb58?branch=89e5fb0a4f0d2e5cf4d53be60033cffb01eebb58&diff=split))


BleepingComputer has recently reported on open-source ecosystems like [PyPI getting flooded](https://www.bleepingcomputer.com/news/security/spammers-flood-pypi-with-pirated-movie-links-and-bogus-packages/) with garbage spam components.


In more serious cases, counterfeit components have been caught getting uploaded to the [npm](https://www.bleepingcomputer.com/news/security/new-linux-macos-malware-hidden-in-fake-browserify-npm-package/) and [RubyGems](https://www.bleepingcomputer.com/news/security/malicious-rubygems-packages-used-in-cryptocurrency-supply-chain-attack/) repositories.


Left unchecked, these malformed, incomplete, or outright malicious packages can pave a way for anything from simple application errors to a successful supply-chain attack.


Although these Winget pull requests, which introduced incomplete information in the applications' manifests, were shortly reverted [[1](http://github.com/OfficialEsco/winget-pkgs/commit/0784bf804aeccb1336babad5d0227ac45c64f24a), [2](https://github.com/microsoft/winget-pkgs/pull/14559)], what is being done to prevent such instances in the future?


Developers propose multiple solutions
-------------------------------------


Following this ongoing incident, multiple developers have suggested workarounds or practices Winget can adopt to ensure the integrity of its packages.


"I really really think that any new *PackageIdentifer* should have to be checked by someone on the Winget team (or if they want to start a recognized contributor system I'd throw my hat in the ring),"  [suggested](https://github.com/microsoft/winget-pkgs/issues/14621#issuecomment-851113786) Easton Pillay, a developer and Winget contributor.


Pillay also believes that fully automating the addition of new Winget packages will introduce tons of duplicates.


In the same thread, the developer also proposed that newly created Winget manifests should require a [manual review](https://github.com/microsoft/winget-pkgs/issues/14621#issuecomment-852098182):


"I know we are trying not to waste the moderator's time, but since [the contributors] are committing known bad metadata by default..., the bot doesn't realize it and then someone who knows that the bug exists has to go back and fix all of the errors (or live with the metadata being wrong, which is a tragedy ;D)," said Pillay.


Microsoft's Demitrius Nelon, a key person behind Winget's development has acknowledged the issue and that he plans to bring it up with the team.


Nelon has also proposed a potential solution:


"One of the options could be requiring a 'second' approver on a 'new' manifest in a 'new' directory."


"The bot has a concept that might work for that scenario. I just don't want to put too much friction and time delay for people submitting manifests, nor too much pressure on 'moderators'."


"We've got a feature on the backlog to detect duplicates. It's more of a warning than a blocking action. We have some expected 'valid' rename scenarios," [explained](https://github.com/microsoft/winget-pkgs/issues/14621#issuecomment-851715546) Nelon.


BleepingComputer has reached out to Microsoft for comment prior to publishing and we are awaiting their response.





## Tags:


### Autogenerated tags:
[[winget]] [[microsoft]] [[github]] [[apps]] [[bleepingcomputer]] [[windows]] [[pillay]] [[nelon]]
