# LastPass source code breach – incident response report released
## Wondering how you’d handle a data breach report if the worst happened to you? Here’s a useful example.
## Information:

+ Link: https://nakedsecurity.sophos.com/2022/09/19/lastpass-source-code-breach-incident-response-report-released/
+ Source: Naked Security
+ Author: Paul Ducklin
+ Date published: 19 September 2022, 18:59
+ Date scraped: 21 September 2022, 15:01

## Article:
![Main article image](https://nakedsecurity.sophos.com/wp-content/uploads/sites/2/2022/08/lp-1200-1.png?w=775)


If the big story of this month looks set to be [Uber’s data breach](https://nakedsecurity.sophos.com/2022/09/16/uber-has-been-hacked-boasts-hacker-how-to-stop-it-happening-to-you/), where a hacker was allegedly able to roam widely through the ride-sharing company’s network…


..the big story from last month was the [LastPass breach](https://nakedsecurity.sophos.com/2022/08/29/lastpass-source-code-breach-do-we-still-recommend-password-managers/), in which an attacker apparently got access to just one part of the LastPass network, but was able to make off with the company’s proprietary source code.


Fortunately for Uber, their attacker seemed determined to make a big, quick PR splash by grabbing screenshots, spreading them liberally online, and taunting the company with shouty messages such as *UBER HAS BEEN HACKED*, right in its own Slack and bug bounty forums:




> [UBER HAS BEEN HACKED, boasts hacker – how to stop it happening to you](https://nakedsecurity.sophos.com/2022/09/16/uber-has-been-hacked-boasts-hacker-how-to-stop-it-happening-to-you/)
> 
> 






The attacker or attackers at LastPass, however, seem to have operated more stealthily, apparently tricking a LastPass developer into installing malware that the cybercriminals then used to hitch a ride into the company’s source code repository:




> [LastPass source code breach – do we still recommend password managers?](https://nakedsecurity.sophos.com/2022/08/29/lastpass-source-code-breach-do-we-still-recommend-password-managers/)
> 
> 






LastPass has now published an [official follow-up report](https://blog.lastpass.com/2022/08/notice-of-recent-security-incident/) on the incident, based on what it has been able to figure out about the attack and the attackers in the aftermath of the intrusion.


We think that the LastPass article is worth reading even if you aren’t a LastPass user, because we think it’s a reminder that a good incident response report is as useful for what it admits you were unable to figure out as for what you were.


## What we now know


The boldface sentences below provide an outline of what LastPass is saying:


* **The attacker *“gained access to the [d]evelopment environment using a developer’s compromised endpoint.”*** We’re assuming this was down to the attacker implanting system-snooping malware on a programmer’s computer.
* **The trick used to implant the malware couldn’t be determined.** That’s disappointing, because knowing how your last attack was actually carried out makes it easier to reassure customers that your revised prevention, detection and response procedures are likely to block it next time. Many potential attack vectors spring to mind, including: unpatched local software, “shadow IT” leading to an insecure local configuration, a phishing click-through blunder, unsafe downloading habits, treachery in the source code supply chain relied on by the coder concerned, or a booby-trapped email attachment opened in error. Hats off to LastPass for admitting to what amounts to a “known unknown”.
* **The attacker *“utilised their persistent access to impersonate the developer once the developer had successfully authenticated using multi-factor authentication.”*** We assume this means that the hacker never needed to acquire the victim’s password or 2FA code, but simply used a [cookie-stealing attack](https://news.sophos.com/en-us/2022/08/18/cookie-stealing-the-new-perimeter-bypass/), or extracted the developer’s authentication token from genuine network traffic (or from the RAM of the victim’s computer) in order to piggy-back on the programmer’s usual access:




> [Cookie stealing: the new perimeter bypass](https://news.sophos.com/en-us/2022/08/18/cookie-stealing-the-new-perimeter-bypass/)
> 
> 






* **LastPass didn’t notice the intrusion immediately, but did detect and expel the attacker within four days.** As we noted in a recent article about the risks of [timestamp ambiguity](https://nakedsecurity.sophos.com/2022/09/09/how-to-deal-with-dates-and-times-without-any-timezone-tantrums/) in system logs, being able to determine the precise order in which events occurred during an attack is a vital part of incident reponse:




> [How to deal with dates and times without any timezone tantrums…](https://nakedsecurity.sophos.com/2022/09/09/how-to-deal-with-dates-and-times-without-any-timezone-tantrums/)
> 
> 






* **LastPass keeps its development and production networks physically separate.** This is a good cybersecurity practice because it prevents an attack on the development network (where things are inevitably in an ongoing state of change and experimentation) from turning into an immediate compromise of the official sofware that’s directly available to customers and the rest of the business.
* **LastPass doesn’t keep any customer data in its development environment.** Again, this is good practice given that developers are, as the job name suggests, generally working on software that has yet to go through a full-on security review and quality assurance process. This separation also makes it believable for LastPass to claim that no password vault data (which would have been encrypted with users’ private keys anyway) could have been exposed, which is a stronger claim than simply saying “we couldn’t find any evidence that it was exposed.” Keeping real-world data out of your development network also prevents well-meaning coders from inadvertently grabbing data that’s meant to be under regulatory protection and using it for unofficial test purposes.
* **Although source code was stolen, no unauthorised code changes were left behind by the attacker.** Of course, we only have LastPass’s own claim to go on, but given the style and tone of rest of the incident report, we can see no reason not to take the company at its word.
* **Source code moving from the development network into production *“can only happen after the completion of rigorous code review, testing, and validation processes”*.** This makes it believable for LastPass to claim that no modified or poisoned source code would have reached customers or the rest of the business, *even if the attacker had managed to implant rogue code* in the version control system..
* **LastPass never stores or even knows its users’ private decryption keys.** In other words, *even if the attacker had made off with password data*, it would have ended up as just so much shredded digital cabbage. (LastPass also provides a [public explanation](https://www.lastpass.com/security/zero-knowledge-security) of how it secures password vault data against offline cracking, including using client-side PBKDF2-HMAC-SHA256 for salting-hashing-and-stretching your offline password with 100,100 iterations, thus making [password cracking attempts](https://nakedsecurity.sophos.com/2013/11/20/serious-security-how-to-store-your-users-passwords-safely/) very much harder even if attackers make off with locally-stored copies of your password vault.)




> [Serious Security: How to store your users’ passwords safely](https://nakedsecurity.sophos.com/2013/11/20/serious-security-how-to-store-your-users-passwords-safely/)
> 
> 






## What to do?


We think it’s reasonable to say that our [early assumptions were correct](https://nakedsecurity.sophos.com/2022/09/01/s3-ep98-the-lastpass-saga-should-we-stop-using-password-managers-audio-text/), and that although this is an embarrassing incident for LastPass, and might reveal trade secrets that the company considered part of its shareholder value…


…this hack can be thought of as LastPass’s own problem to deal with, because no customer passwords were reached, let alone cracked, in this attack:




> [S3 Ep98: The LastPass saga – should we stop using password managers? [Audio + Text]](https://nakedsecurity.sophos.com/2022/09/01/s3-ep98-the-lastpass-saga-should-we-stop-using-password-managers-audio-text/)
> 
> 






This attack, and LastPass’s own incident report, are also a good reminder that “divide and conquer”, also known by the jargon term [Zero Trust](https://www.sophos.com/en-us/products/zero-trust-network-access), is an important part of contemporary cyberdefence.


As Sophos expert Chester Wisniewski explains in his analysis of the [recent Uber hack](https://nakedsecurity.sophos.com/2022/09/17/s3-ep100-5-uber-breach-an-expert-speaks-audio-text/), there’s a lot more at stake if crooks who get access to *some* of your network can roam around wherever they like in the hope of getting access to *all* of it:



*Click-and-drag on the soundwaves below to skip to any point. You can also [listen directly](https://soundcloud.com/sophossecurity/s3-ep1005-uber-breach-an-expert-speaks) on Soundcloud.*





---





## Tags:


### Autogenerated tags:
[[lastpass]] [[uber]] [[malware]]
