# Thousands of publicly-exposed Apache Superset installs exposed to RCE attacks
## Apache Superset open-source data visualization platform is affected by an insecure default configuration that could lead to remote code execution. Apache Superset is an open-source data visualization and data exploration platform. The maintainers of the software have released security patches to address an insecure default configuration, tracked as CVE-2023-27524 (CVSS score: 8.9), that could lead to remote […]
## Information:

+ Link: https://securityaffairs.com/145317/hacking/superset-flaw.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 26 April 2023, 13:34
+ Date scraped: 26 April 2023, 14:00

## Article:
![Main article image](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2023/04/image-46.png?resize=300%2C222&ssl=1)


## [Apache Superset](https://github.com/apache/superset) open-source data visualization platform is affected by an insecure default configuration that could lead to remote code execution.


Apache Superset is an open-source data visualization and data exploration platform. The maintainers of the software have released security patches to address an insecure default configuration, tracked as [**CVE-2023-27524**](https://nvd.nist.gov/vuln/detail/CVE-2023-27524) (CVSS score: 8.9), that could lead to remote code execution.


The issue was discovered by Horizon3 researchers who reported that there are more than 3000 instances of the platform exposed to the Internet. Horizon3 found that at least 2000 servers are running with a dangerous default configuration.


*“Session Validation attacks in Apache Superset versions up to and including 2.0.1. Installations that have not altered the default configured SECRET\_KEY according to installation instructions allow for an attacker to authenticate and access unauthorized resources.” [reads the advisory](https://nvd.nist.gov/vuln/detail/CVE-2023-27524). “This does not affect Superset administrators who have changed the default value for SECRET\_KEY config.”*


The CVE-2023-27524 flaw impacts versions up to and including 2.0.1.


Vulnerable versions are using the following default value for the SECRET\_KEY:


“\x02\x01thisismyscretkey\x01\x02\\e\\y\\y\\h”


*“Any attacker can “log in” to these servers with administrative privileges, access and modify data connected to these servers, harvest credentials, and execute remote code.” [reported](https://www.horizon3.ai/cve-2023-27524-insecure-default-configuration-in-apache-superset-leads-to-remote-code-execution/) Horizon3.*


*“The web application signs the cookie with a SECRET\_KEY, a value that is supposed to be randomly generated and typically stored in a local configuration file. With every web request, the browser sends the signed session cookie back to the application. The application then validates the signature on the cookie to re-authenticate the user prior to processing the request. The security of the web application depends critically on ensuring the SECRET\_KEY is actually secret. If the SECRET\_KEY is exposed, an attacker with no prior privileges could generate and sign their own cookies and access the application, masquerading as a legitimate user.”*


Horizon3 researchers reported the issue to the Superset team in Oct. 2021, but when in February 2023 they checked the fix they discovered that in January 2022 the default `SECRET_KEY` value was changed to “`CHANGE_ME_TO_A_COMPLEX_RANDOM_SECRET`“, and a warning was added to the logs with this Git [commit](https://github.com/apache/superset/commit/412189fcb73268ddd4829d2fdb8381c5e47595ce).


[![Superset](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2023/04/image-46.png?resize=1024%2C200&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2023/04/image-46.png?ssl=1)


The experts also found two additional SECRET\_KEY configurations using the values “[YOUR\_OWN\_SECURE\_RANDOM\_KEY](https://superset.apache.org/docs/installation/configuring-superset/)” and “[thisISaSECRET\_1234](https://github.com/apache/superset/blob/85da86dc81cf9f5c4791a817befd3d7961ce97ac/helm/superset/templates/_helpers.tpl).”


The experts found 3390 Superset instances exposed online, of which 3176 appeared to be really Superset instances. The researchers discovered that 2124 (~67%) out of 3176 instances were using one of the above four default keys.


Some of these installs belong to large corporations, small companies, government agencies, and universities.


Horizon3 shared its findings with the Apache security team a second time, and the project maintainers addressed the issue with the release of [version 2.1](https://github.com/apache/superset/releases/tag/2.1.0) on April 5, 2023.


*“This fix is not foolproof though as it’s still possible to run Superset with a default `SECRET_KEY` if it’s installed through a [docker-compose file](https://github.com/apache/superset/blob/master/docker-compose-non-dev.yml) or a [helm template](https://github.com/apache/superset/blob/master/helm/superset/templates/_helpers.tpl). The docker-compose file contains a new default `SECRET_KEY` of `TEST_NON_DEV_SECRET` that we suspect some users will unwittingly run Superset with. Some configurations also set admin/admin as the default credential for the admin user.” concludes the researchers who also released a [Python script](https://github.com/horizon3ai/CVE-2023-27524) to determine if Superset instances are vulnerable.*


**Blogger Awards 2022 – VOTE FOR YOUR WINNERS**  
**Vote for me in the sections:**


* The Teacher – Most Educational Blog
* The Entertainer – Most Entertaining Blog
* The Tech Whizz – Best Technical Blog
* Best Social Media Account to Follow (@securityaffairs)


Please nominate Security Affairs as your favorite blog.



> 
> 
> > 
> > **Nominate here: <https://docs.google.com/forms/d/e/1FAIpQLSfaFMkrMlrLhOBsRPKdv56Y4HgC88Bcji4V7OCxCm_OmyPoLw/viewform>**
> > 
> > 
> > 
> 
> 
> 


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking,** **Superset**)



  


---


  




## Tags:
***CVE's***: CVE-2023-27524
***urls***: https://docs.google.com/forms/d/e/1FAIpQLSfaFMkrMlrLhOBsRPKdv56Y4HgC88Bcji4V7OCxCm_OmyPoLw/viewform

### Autogenerated tags:
[[secret_key]] [[horizon3]] [[blog]]
