# Google Messages Getting Cross-Platform End-to-End Encryption with MLS Protocol
## Google is adding support for Message Layer Security (MLS) to its Messages service for Android.
## Information:

+ Link: https://thehackernews.com/2023/07/google-messages-getting-cross-platform.html
+ Source: The Hacker News
+ Author: THN
+ Date published: 24 July 2023, 18:14
+ Date scraped: 24 July 2023, 14:01

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiU-fTBHnPGsieFPhrQxyeTlZNUYySrYpsT2ZpQOoEs-L4HlfPWufbVokEpUYkVO-QfdVqdTm2U0d1WCicjJalUYBacG_oyDrcEz6cHDYGCFBs84moRq_o7Qs-_JvFPNESXMSHFZrVboXmxMyPFjD-1YmiSVbj5Rpy25MNwbAp1Gmlg8dMAhCzIwmwLxJoN/s728-e3650/privacy.jpg)


Google has announced that it intends to add support for Message Layer Security ([MLS](https://openmls.tech/)) to its Messages service for Android and open source implementation of the specification.


"Most modern consumer messaging platforms (including Google Messages) support end-to-end encryption, but users today are limited to communicating with contacts who use the same platform," Giles Hogben, privacy engineering director at Google, [said](https://security.googleblog.com/2023/07/an-important-step-towards-secure-and.html). "This is why Google is strongly supportive of regulatory efforts that require interoperability for large end-to-end messaging platforms."


The development comes as the Internet Engineering Task Force (IETF) [released](https://www.ietf.org/blog/mls-protocol-published/) the core specification of the Messaging Layer Security (MLS) protocol as a Request for Comments ([RFC 9420](https://datatracker.ietf.org/doc/rfc9420/)).


Some of the other major companies that have thrown their weight behind the protocol are Amazon Web Services (AWS) Wickr, Cisco, Cloudflare, The Matrix.org Foundation, Mozilla, Phoenix R&D, and Wire. Notably missing from the list is Apple, which offers [iMessage](https://thehackernews.com/2023/07/apple-threatens-to-pull-imessage-and.html).


MLS, as the name implies, is a [security layer](https://messaginglayersecurity.rocks/) for end-to-end encryption that facilitates interoperability across messaging services and platforms. It was approved for publication as a standard by IETF in March 2023.


"MLS builds on the best lessons of the current generation of security protocols," IETF [noted](https://www.ietf.org/blog/mls-secure-and-usable-end-to-end-encryption/) at the time. "Like the widely used [Double Ratchet protocol](https://signal.org/docs/specifications/doubleratchet/), MLS allows for asynchronous operation and provides advanced security features such as post-compromise security. And, like [TLS 1.3](https://www.ietf.org/blog/tls13/), MLS provides robust authentication."


Central to MLS is an approach known as [Continuous Group Key Agreement](https://eprint.iacr.org/2020/752) ([CGKA](https://eprint.iacr.org/2021/1456)) that allows multiple messaging clients to agree on a shared key that caters to groups in size ranging from two to thousands in a manner that offers forward secrecy guarantees regardless of the individuals who join and leave the group conversation.

 "The core functionality of MLS is continuous group authenticated key exchange (AKE)," the standard document [reads](https://www.rfc-editor.org/rfc/rfc9420.html). "As with other authenticated key exchange protocols (such as TLS), the participants in the protocol agree on a common secret value, and each participant can verify the identity of the other participants."


"That secret can then be used to protect messages sent from one participant in the group to the other participants using the MLS framing layer or can be exported for use with other protocols. MLS provides group AKE in the sense that there can be more than two participants in the protocol, and continuous group AKE in the sense that the set of participants in the protocol can change over time."


This evolving membership is realized by means of a data structure called an asynchronous ratcheting tree, which is used to derive shared secrets among a group of clients. The goal is to be able to efficiently remove any member, achieving [post-compromise security](https://eprint.iacr.org/2016/221) by preventing group messages from being intercepted even if one member was breached at some point in the past.


On the other hand, forward secrecy, which enables messages sent at a certain point in time to be secured in the face of later compromise of a group member, is provided by deleting private keys from past versions of the ratchet tree, thereby averting old group secrets from being re-derived.


Mozilla, which is hoping to see a standardization of a Web API to leverage the protocol directly via web browsers, [said](https://blog.mozilla.org/en/mozilla/messaging-layer-security-is-now-an-internet-standard/) MLS is designed such that "the legitimacy of new members entering a group is checked by everyone: there is nowhere to hide."


  





## Tags:


### Autogenerated tags:
[[mls]] [[google]] [[end-to-end]] [[ietf]]
