# Predictive AI in Cybersecurity: Outcomes Demonstrate All AI is Not Created Equally
## Discover how predictive AI is shaping the future of cybersecurity. Learn how BlackBerry's Cylance AI is outperforming the competition in malware.
## Information:

+ Link: https://thehackernews.com/2023/11/predictive-ai-in-cybersecurity-outcomes.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 03 November 2023, 16:56
+ Date scraped: 03 November 2023, 12:01

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEh0tm9w2iopw4PAi0kSz3uS-19vmHZIozDnNGXWgyGnd94sLaQKLKF1rzq2TVwkQO7MpODbQqHPPeHD4bEFOYB2eisDdhz3a5Oqay17qDLvG9D5HyS9LuZU0DPQ9tbwJRdhTNa1Ibv_PZUllKQ1ySvLXIJEeXZMRW-ztle2kus1nK_Km24k_OgXsvV9Kv8/s728-rw-ft-e30/black.png)


Here is what matters most when it comes to artificial intelligence (AI) in cybersecurity: Outcomes.


As the threat landscape evolves and [generative AI is added](https://www.blackberry.com/us/en/company/newsroom/press-releases/2023/blackberry-announces-generative-ai-powered-cybersecurity-assistant?utm_medium=paid_digital&utm_source=hackernews&utm_campaign=fy24-q3_ues_cylanceai-thn-ai-pr-art-tdc&utm_content=article1103) to the toolsets available to defenders and attackers alike, evaluating the relative effectiveness of various [AI-based security](https://www.blackberry.com/us/en/solutions/endpoint-security/cybersecurity-ai?utm_medium=paid_digital&utm_source=hackernews&utm_campaign=fy24-q3_ues_cylanceai-thn-ai-pr-art-tdc&utm_content=article1103) offerings is increasingly important — and difficult. Asking the right questions can help you spot solutions that deliver value and ROI, instead of just marketing hype. Questions like, "Can your predictive AI tools sufficiently block what's new?" and, "What actually signals success in a cybersecurity platform powered by artificial intelligence?"



As BlackBerry's AI and ML (machine learning) patent portfolio attests, BlackBerry is a leader in this space and has developed an exceptionally well-informed point of view on what works and why. Let's explore this timely topic.


**Evolution of AI in Cybersecurity**[#](#evolution-of-ai-in-cybersecurity)
--------------------------------------------------------------------------


Some of the earliest uses of ML and AI in cybersecurity date back to the development of the CylancePROTECT® EPP ([endpoint protection platform](https://www.blackberry.com/us/en/solutions/endpoint-security/endpoint-protection-platform?utm_medium=paid_digital&utm_source=hackernews&utm_campaign=fy24-q3_ues_cylanceai-thn-ai-pr-art-tdc&utm_content=article1103)) more than a decade ago. Predicting and preventing new malware attacks is arguably more crucial today, as generative AI helps threat actors rapidly write and test new code. The most recent BlackBerry [Global Threat Intelligence Report](https://blogs.blackberry.com/en/2023/08/unique-malware-public-sector-attack-surge-threat-report-aug?utm_medium=paid_digital&utm_source=hackernews&utm_campaign=fy24-q3_ues_cylanceai-thn-ai-pr-art-tdc&utm_content=article1103) uncovered a 13% surge in novel malware attacks, quarter over quarter. Preventing these attacks is an ongoing challenge but thankfully, the evolution in attacks is being met by an evolution in technology.


BlackBerry's data science and machine learning teams are dedicated to enhancing the performance of their predictive AI tools. Recent third-party tests confirm that Cylance ENDPOINT® successfully blocks 98.9% of threats by actively predicting malware behavior, even for new variants. This achievement is the result of a decade of innovation, experimentation, and evolution in AI techniques, including a shift from supervised human labeling to a composite training approach. This approach, which combines unsupervised, supervised, and active learning in both cloud and local environments, has been refined by analyzing extensive data over time, resulting in a highly effective model capable of accurately predicting and anticipating new threats.


**Temporal Advantage: Taking Time Into Account**[#](#temporal-advantage-taking-time-into-account)
-------------------------------------------------------------------------------------------------


The quality and effectiveness of ML models are often discussed in terms of size, parameters, and performance. However, the critical aspect of ML models, particularly in cybersecurity, is their ability to detect and respond to threats in real-time. In the context of malware pre-execution protection, where threats must be identified and blocked before execution, the temporal aspect is crucial.


Temporal resilience, which measures a model's performance against both past and future attacks, is essential for threat detection. Temporal Predictive Advantage (TPA) is a metric used to assess a model's ability to perform over time, especially in detecting zero-day threats.


This testing involves training models with past malware classes and testing them against newer malware, validating their performance over time. This is particularly important for endpoints that are not always cloud-connected, where frequent model updates may not be feasible.


A model's reliance on frequent updates can indicate its immaturity. In contrast, BlackBerry Cylance's model has demonstrated a strong temporal predictive advantage, maintaining high detection rates without frequent model updates, as illustrated in the chart showing the TPA over months for the fourth-generation Cylance model.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgN5ZtjmaJ-pGWkP3Y7TqAjLJuBgrEk1yUQh_6uREBDc-hfm8J9_bOmr-OdDKGvrJikl7RrGQyPMMoxm7f32dkYqUakjJYh4nUj1r1oM2aNkk_Sm2q90aynqrab3dHRyVANDEnu4D72LwAZ1FYRI1_YchoslQfv5wZmKssgb6hEnATylUBRAc-qpyX2gHs/s728-rw-ft-e30/map.jpg)
Protection continued for up to 18 months without a model update and reveals model maturity and precise model training. This does not happen by accident.


Mature AI Predicts and Prevents Future Evasive Threats has a novel ML model inference technology that sets it apart. It can deduce, or "infer" whether something is a threat, even when it has never seen it before. BlackBerry's approach utilizes a unique hybrid method of distributed inference, a concept conceived seven years ago, before the availability of ML libraries and model-serving tools. The result of this approach is our latest model, which represents the pinnacle of innovation and improvements over the many generations of this technology.


**Predicting Malware: The Most Mature Cylance Model**[#](#predicting-malware-the-most-mature-cylance-model)
-----------------------------------------------------------------------------------------------------------


Built upon vast and diverse datasets with extensive malware behavior insights, our latest model surpasses all previous versions in performance, particularly in temporal predictive advantage. With over 500 million samples and billions of features evaluated, BlackBerry Cylance AI delivers outstanding results and operates with impressive speed for distributed inference.


As we continue to advance in applying ML to cybersecurity, our commitment to innovation remains strong. Given the increasing use of AI by adversaries, it's essential to prioritize effective defensive cybersecurity measures that yield meaningful outcomes.


With a multi-year predictive advantage, Cylance AI has protected businesses and governments globally from cyberattacks since its inception. BlackBerry's Cylance AI helps customers stop 36% more malware, 12x faster, and with 20x less overhead than the competition These outcomes demonstrate that not all AI is created the same. And not all AI is Cylance AI.


*Want to learn more about predictive AI? Click* [***here***](https://blogs.blackberry.com/en/2023/10/predictive-ai-in-cybersecurity?utm_medium=paid_digital&utm_source=hackernews&utm_campaign=fy24-q3_ues_cylanceai-thn-ai-pr-art-tdc&utm_content=article1103) *to read the detailed BlackBerry research article and explore related content and for similar articles and news delivered straight to your inbox,* [*subscribe to the* ***BlackBerry Blog***](https://blogs.blackberry.com/en/home#:~:text=Sign%20up%20to%20get%20the%20latest%20from%20BlackBerry%20Blogs%20straight%20to%20your%20inbox.)*.*



#### **Related Reading**[#](#related-reading)


* [BlackBerry Supports Canada's Voluntary Code of Conduct for Generative AI](https://blogs.blackberry.com/en/2023/09/bb-supports-canada-voluntary-generative-ai-conduct-code?utm_medium=paid_digital&utm_source=hackernews&utm_campaign=fy24-q3_ues_cylanceai-thn-ai-pr-art-tdc&utm_content=article1103)
* [Microsoft Defender vs. CylanceENDPOINT®](https://blogs.blackberry.com/en/2023/08/ms-defender-vs-cylance-endpoint?utm_medium=paid_digital&utm_source=hackernews&utm_campaign=fy24-q3_ues_cylanceai-thn-ai-pr-art-tdc&utm_content=article1103)
* [Why Are So Many Organizations Banning ChatGPT?](https://blogs.blackberry.com/en/2023/08/why-companies-ban-chatgpt-ai?utm_medium=paid_digital&utm_source=hackernews&utm_campaign=fy24-q3_ues_cylanceai-thn-ai-pr-art-tdc&utm_content=article1103)
* [Tolly Test Report on BlackBerry CylanceENDPOINT](https://www.blackberry.com/us/en/pdfviewer?file=/content/dam/resources/blackberry-com/resource-library/en/cyber/2023/standard/rp/rp-tolly-group-cylanceendpoint-by-blackberry-comparative-endpoint-protection-test-report.pdf)


**Note -** This article has been expertly written by Shiladitya Sircar, SVP, Product Engineering & Data Science at BlackBerry, where he leads Cyber Security R&D teams.



![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)

  





## Tags:


### Autogenerated tags:
[[malware]] [[cylance]] [[cybersecurity]]
