# Researchers found DoS flaws in popular BGP implementation
## Vulnerabilities in a software implementation of the Border Gateway Protocol (BGP) that could be weaponized to trigger a DoS condition on BGP peers. Forescout Vedere Labs researchers discovered multiple vulnerabilities in the software implementation of the Border Gateway Protocol (BGP). The issues reside in the BGP message parsing in version 8.4 of FRRouting implementation, a […]
## Information:

+ Link: https://securityaffairs.com/145676/security/bgp-frrouting-flaws.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 03 May 2023, 07:17
+ Date scraped: 03 May 2023, 09:00

## Article:
![Main article image](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2023/05/BGP-flaws.png?resize=300%2C300&ssl=1)


## Vulnerabilities in a software implementation of the Border Gateway Protocol (BGP) that could be weaponized to trigger a DoS condition on BGP peers.


Forescout Vedere Labs researchers discovered multiple vulnerabilities in the software implementation of the Border Gateway Protocol (BGP). The issues reside in the BGP message parsing in version 8.4 of FRRouting implementation, a leading open-source implementation of the protocol. The flaw can be exploited to trigger a denial of service (DoS) condition on vulnerable BGP peers.


Technically the flaws can be exploited to drop all BGP sessions and routing tables, rendering the peer unresponsive.


The researchers pointed out that Border Gateway Protocol implementations are widely adopted, common uses include traffic routing in [large data centers](https://research.facebook.com/publications/running-bgp-in-data-centers-at-scale/) and BGP extensions, such as [MP-BGP](https://en.wikipedia.org/wiki/Multiprotocol_BGP), or for [MPLS L3 VPN](https://en.wikipedia.org/wiki/MPLS_VPN#Layer_3_VPN_(VPRN))s. 


The FRRouting implementation is currently used in the networking solutions of several major vendors, including [nVidia Cumulus](https://www.nvidia.com/en-us/networking/ethernet-switching/cumulus-linux/), [DENT](https://dent.dev/), and [SONiC](https://sonic-net.github.io/SONiC/).


*“Attackers may leverage any of the three new vulnerabilities to achieve a DoS on a vulnerable BGP peer, thus dropping all BGP sessions and routing tables and rendering the peer unresponsive for several seconds. The DoS condition may be prolonged indefinitely by repeatedly sending malformed packets.” reads the [advisory](https://www.forescout.com/blog/three-new-bgp-message-parsing-vulnerabilities-disclosed-in-frrouting-software/) published by the company.*


The discovery is the result of a broader analysis of seven popular Border Gateway Protocol implementations, three open-source ([FRRouting](https://frrouting.org/), [BIRD](https://bird.network.cz/), [OpenBGPd](https://www.openbgpd.org/)) and four closed source ([Mikrotik RouterOS](https://mikrotik.com/software), [Juniper JunOS](https://www.juniper.net/us/en/products/network-operating-system/junos-os.html), [Cisco IOS](https://www.cisco.com/c/en/us/products/ios-nx-os-software/index.html), [Arista EOS](https://www.arista.com/en/products/eos)).


Below is the list of the flaws discovered by Forescout:




| **CVE ID** | **Description** | **CVSSv3.1** | **Potential Impact** |
| --- | --- | --- | --- |
| CVE-2022-40302 | Out-of-bounds read when processing a malformed BGP OPEN message with an *Extended Optional Parameters Length* option. | [6.5](https://www.first.org/cvss/calculator/3.1#CVSS:3.1/AV:N/AC:L/PR:L/UI:N/S:U/C:N/I:N/A:H) | DoS |
| CVE-2022-40318 | Out-of-bounds read when processing a malformed BGP OPEN message with an *Extended Optional Parameters Length* option. This is a different issue from CVE-2022-40302. | [6.5](https://www.first.org/cvss/calculator/3.1#CVSS:3.1/AV:N/AC:L/PR:L/UI:N/S:U/C:N/I:N/A:H) | DoS |
| CVE-2022-43681 | Out-of-bounds read when processing a malformed BGP OPEN message that abruptly ends with the option length octet (or the option length word, in case of OPEN with extended option lengths message). | [6.5](https://www.first.org/cvss/calculator/3.1#CVSS:3.1/AV:N/AC:L/PR:L/UI:N/S:U/C:N/I:N/A:H) | DoS |




The researchers pointed out that the flaws CVE-2022-40302 and CVE-2022-43681 can be triggered before FRRouting validates BGP Identifier and ASN fields. While FRRouting only allows connections between configured peers by default (e.g., OPEN messages from hosts not present in the config files will not be accepted), in the attack scenario described in the advisory, threat actors can spoof a valid IP address of a trusted peer. Threat actors can also [take advantage of misconfigurations](https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2020-3165) or attempt to compromise a legitimate peer by exploiting other vulnerabilities. 


It has been estimated that there are over 330,000 [hosts with BGP enabled](https://www.shodan.io/search?query=product%3Abgp) on the internet and approximately 1,000 of them [replies to unsolicited BGP OPEN messages](https://www.shodan.io/search?query=%28bgp+port%3A%22179%22+%29+AND+NOT%28Error+Code%29). Most of the Border Gateway Protocol hosts are in China (close to 100,000), the US (50,000) and the UK (16,000). The experts discovered more than 1,000 hosts running [FRRouting](https://www.shodan.io/search?query=Hello%2C+this+is+frrouting), but not all of them have Border Gateway Protocol enabled. Again. 



[![BGP flaws](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2023/05/BGP-flaws.png?resize=701%2C359&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2023/05/BGP-flaws.png?ssl=1)


The vulnerabilities were addressed by the FRRouting team with the release of the following versions:


* CVE-2022-40302 and CVE-2022-40318: [https://github.com/FRRouting/frr/pull/12043](https://protect-us.mimecast.com/s/jIGKCn5V3vc3wN8zhZGyty?domain=github.com)
* CVE-2022-43681: <https://github.com/FRRouting/frr/pull/12247>


*“Our research shows that modern BGP implementations still have low-hanging fruit that can be abused by attackers.” concludes the advisory.*


Forescout also released a Python-based open-source [fuzzer tool](https://github.com/Forescout/bgp_boofuzzer/) that allows organizations to test the security of the Border Gateway Protocol suites used internally and find new vulnerabilities in Border Gateway Protocol implementations.



> 
> **Please vote for Security Affairs (<https://securityaffairs.com/>) as the best European Cybersecurity Blogger Awards 2022 – VOTE FOR YOUR WINNERS**  
> **Vote for me in the sections:**
> 
> 
> 


* The Teacher – Most Educational Blog
* The Entertainer – Most Entertaining Blog
* The Tech Whizz – Best Technical Blog
* Best Social Media Account to Follow (@securityaffairs)


Please nominate Security Affairs as your favorite blog.



> 
> 
> > 
> > **Nominate here: <https://docs.google.com/forms/d/e/1FAIpQLSfaFMkrMlrLhOBsRPKdv56Y4HgC88Bcji4V7OCxCm_OmyPoLw/viewform>**
> > 
> > 
> > 
> 
> 
> 


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking,** **Border Gateway Protocol**)




  


---


  




## Tags:
***CVE's***: CVE-2022-40318 CVE-2022-40302 CVE-2022-43681
***urls***: https://github.com/FRRouting/frr/pull/12043 https://docs.google.com/forms/d/e/1FAIpQLSfaFMkrMlrLhOBsRPKdv56Y4HgC88Bcji4V7OCxCm_OmyPoLw/viewform https://github.com/FRRouting/frr/pull/12247 https://securityaffairs.com/

### Autogenerated tags:
[[bgp]] [[frrouting]] [[blog]] [[forescout]] [[open-source]]
