# The commercial satellite boom is leaving space vulnerable to hackers
## U.S. lawmakers and other researchers are seeking solutions for securing our increasingly satellite-crowded skies.
## Information:

+ Link: https://therecord.media/the-commercial-satellite-boom-is-leaving-space-vulnerable-to-hackers/
+ Source: The Record
+ Author: Andrea Peterson
+ Date published: 29 July 2022, 19:50
+ Date scraped: 29 July 2022, 20:00

## Article:
![Main article image](https://therecord.media/wp-content/uploads/2022/07/satellite-nasa.jpg)


Humanity’s imagination turned toward the heavens this month as the James Webb Space Telescope revealed images of distant galaxies.


But John Crassidis, who worked on initial designs for the telescope at NASA during the 1990s, is focused on something closer to home: securing the thousands of human-made satellites orbiting the Earth — many of which are now controlled by the private sector. And Crassidis, now the director of the Center for Space Cyber Strategy and Cyber Security at the University of Buffalo, is waiting for one of them to be wiped out by a cyberattack.  
  
“I don’t think it’s a question of if, I think it’s a question of when,” he told The Record.


He’s not the only one who is worried: U.S. lawmakers and other researchers are seeking solutions for securing our increasingly crowded skies.


“We need to make every effort to understand what further actions can be and should be taken to strengthen cybersecurity for civil and commercial space systems, including commercial space systems that provide mission-critical government data and services,“ said Subcommittee on Space and Aeronautics Chairman Rep. Don Beyer (D-VA) in a Thursday hearing.


As more nations and private entities have the capacity to launch spacecraft into orbit, the number of satellites surrounding the earth has skyrocketed up to 7,895, according to [data](https://www.unoosa.org/oosa/osoindex/search-ng.jspx?lf_id=#?c=%7B%22filters%22:%5B%7B%22fieldName%22:%22en%23object.status.inOrbit_s1%22,%22value%22:%22Yes%22%7D,%7B%22fieldName%22:%22en%23object.status.objectStatus_s1%22,%22value%22:%22in%20orbit%22%7D%5D,%22sortings%22:%5B%7B%22fieldName%22:%22object.launch.dateOfLaunch_s1%22,%22dir%22:%22desc%22%7D%5D%7D) from the United Nations Office for Outer Space Affairs. 


Many are private communications satellites now being used to provide internet access that can be a lifeline to isolated areas or when local infrastructure is disrupted in conflict.


However, those lifelines can still be vulnerable to cyberattacks — a problem highlighted by a cyberattack that disrupted satellite internet provider Viasat during the invasion of Ukraine. The U.S. and European allies [attributed](https://therecord.media/eu-uk-blame-russia-for-ukraine-satellite-hack/) that attack to Russia. 


“For commercial vendors, they are driven by the consumers of the services that are being used — so they may not be as willing to pay for security as a [Defense Department] or civil agency would because they are required to do so,” Theresa Suloway, Space Cybersecurity Engineer at MITRE Corporation, testified.


But even while some U.S. agencies work to provide guidance for how to secure commercial satellites, many remain vulnerable to attacks that could interfere with communications capabilities on Earth or put them on a crash course with other space objects.


Such an attack could have long-term consequences for humanity’s navigation of local space.


“A collision between satellites would not only destroy the satellites involved, but the resulting debris would permanently remove that orbit or region from use by any other satellite,” said Suloway. “This risk requires pre-emptive rather than reactive action.”


Even without such attacks, space is already getting crowded with debris. NASA reported last year that it’s tracking [more than 27,000](https://www.nasa.gov/mission_pages/station/news/orbital_debris.html) pieces of space junk that are already [creating challenges for spaceflight](https://www.space.com/space-junk-collision-chinese-satellite-yunhai-1-02) and likely to cascade — a pollution problem known as “Kessler Syndrome” after NASA scientist Donald Kessler who raised concerns about the risks in the 1970s.


## **The final frontier for cybersecurity**


Protecting a satellite involves securing both the object in orbit as well as the ground control station used to communicate with it. The ground stations are generally easier targets for digital attackers, but both can be vulnerable, Suloway testified to the space and aeronautics subcommittee.


For example, satellites rely on solar panels that must be carefully positioned to stay powered — so losing control of the systems that angle them may cause them to be knocked permanently offline in a matter of days, according to Crassidis.


“It doesn’t take too much to hack into a satellite, turn it — and if we can’t get control back, it’s dead,” he said. “The power is very limited on satellites.”


Cyberattacks on satellites are thought to be rare, but they’ve happened before.  
  
For example, Beyer noted in his opening remarks that the U.S.-China Economic Security and Review Commission previously [reported](https://books.google.com/books?id=EWsrAPFx-88C&pg=PA216&lpg=PA216&dq=%22achieved+all+steps+required+to+command+the+satellite+but+did+not+issue+commands%22&source=bl&ots=ZfCVqlTg_q&sig=ACfU3U1UekQsI332z5aMs9EvrxHOBqBSNw&hl=en&sa=X&ved=2ahUKEwiS2cnG4575AhXQFFkFHTPEDaQQ6AF6BAgTEAM#v=onepage&q=%22achieved%20all%20steps%20required%20to%20command%20the%20satellite%20but%20did%20not%20issue%20commands%22&f=false) on hacks targeting U.S. government satellites, including an incident where a cyberattacker “achieved all steps required to command [a NASA earth observation satellite], but did not issue commands.”


Crassidis is especially concerned that channels used to transmit commands to commercial satellites may be known and open.


“The communication bands are pretty standard bands,” Crassidis said.


In her testimony Thursday, Suloway said securing those channels is an important step towards protecting the commercial space sector — including with encryption modules that are able to be upgraded to [quantum algorithms](https://therecord.media/nist-selects-first-group-of-quantum-resistant-encryption-tools/).


“Adding encryption to the groundspace link would mitigate some of the vulnerabilities by making it harder for malicious sources to send commands to the satellites,” she said.


The Federal Communications Commission (FCC) [previously considered](https://www.fcc.gov/document/fcc-updates-orbital-debris-mitigation-rules-new-space-age-0) including encryption requirements as part of regulations related to commercial spacecraft in 2020, but didn’t. 


“It’s a big concern and the FCC keeps punting,” said Crassidis.


But it’s not the only concern about digitally securing satellites.


“Monitoring and situational awareness need to be built in now as part of the fabric of commercial space,” Suloway said, including best practices for digitally securing ground stations as well as satellites.


Developing guides that can lower the entry for using commercially available cybersecurity products can help the commercial space sector improve security without forcing them to do their own experimentation, she added.


Suloway testified in favor of incentivizing commercial sector information-sharing through voluntary collaborations, rather than regulatory approaches to getting the private sector on board — in part, she said, out of concerns that commercial space companies would choose to launch from other parts of the world where they did not have to comply. This might risk the U.S. losing out on a slice of a market that the Space Foundation [reports](https://www.spacefoundation.org/2022/07/27/the-space-report-2022-q2/) attracted $224 billion in revenue last year. 


Much of the U.S. government’s recent policy moves follow this public-private partnership approach. In 2020, the Trump administration issued [Space Policy Directive-5](https://history.nasa.gov/SPD-5.pdf), which ordered U.S. government agencies to “further define best practices, establish cybersecurity informed norms, and promote improved cybersecurity behaviors throughout the Nation’s industrial base for space systems.” 


The next year, the Cybersecurity and Infrastructure Security Agency (CISA) [announced](https://www.cisa.gov/news/2021/05/13/cisa-launches-space-systems-critical-infrastructure-working-group) the creation of a Space Systems Critical Infrastructure Working Group and the National Institute of Standards and Technology (NIST) [issued](https://csrc.nist.gov/publications/detail/nistir/8270/archive/2021-06-29) the first draft of new cybersecurity guidance for commercial satellite operators. 


Following the Viasat attack, CISA and the FBI issued [an advisory](https://therecord.media/cisa-fbi-warn-of-satellite-network-hacks-following-viasat-cyberattack/), while the National Security Agency issued [new guidance](https://media.defense.gov/2022/May/10/2002993519/-1/-1/0/CSA_PROTECTING_VSAT_COMMUNICATIONS_05102022.PDF) on protecting satellite internet systems and lawmakers [introduced legislation](https://www.scmagazine.com/analysis/device-security/congress-wants-to-study-the-cybersecurity-of-satellites-after-viasat-hack) about studying how to prevent such attacks. 


However, these efforts represent best practices — not rules that the government can compel companies to follow. And with more satellites going up every year, the threat of attacks is only on the rise.


“Right now in space, it’s the wild, wild west – it’s kind of scary when you think about it,” Crassidis said.





## Tags:


### Autogenerated tags:
[[cybersecurity]] [[crassidis]] [[u.s]] [[suloway]]
